# Yuhi (यूँ ही)

|                |                                                                                             |
|----------------|---------------------------------------------------------------------------------------------|
| Compatibility  | ![Py-Version]                                                                               |
| Quality Checks | [![lint check][lint-badge]]() [![tests][tests-badge]]() [![pre-commit][pre-commit-badge]]() |
| Package        | ![pypi-v] ![pypi-downloads]                                                                 |
| MetaData       | [![license-badge]][license]                                                                 |                                                                                                                                                                                           

A simple Python CLI toolkit to automate project enhancement using standard config templates.
> Yuhi /y-oo-n-h-ee/ is a Hindi word meaning "casually" or "at random"

## Installation

```
pip install yuhi
```

## Usage

![help_txt](extras/help_txt.png)


---
Made with 💚

[license]: https://github.com/rsb-23/yuhi/blob/main/LICENSE
[lint-badge]: https://github.com/rsb-23/yuhi/actions/workflows/code-lint.yml/badge.svg
[tests-badge]: https://github.com/rsb-23/yuhi/actions/workflows/code-test.yml/badge.svg

[license-badge]: https://img.shields.io/badge/License-MIT-blue.svg
[pre-commit-badge]: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
[py-version]: https://img.shields.io/pypi/pyversions/yuhi
[pypi-downloads]: https://img.shields.io/pypi/dm/yuhi?label=Downloads
[pypi-v]: https://img.shields.io/pypi/v/yuhi?label=latest
